@@ -25,11 +25,17 @@ class ArgumentType(Enum):
 
 
 class BaseArgument(ABC):
-    """項の基底クラス．"""
+    """項の基底クラス．
 
-    def __init__(self, arg_type: ArgumentType) -> None:
-        self.type: ArgumentType = arg_type
-        self.optional = False
+    Args:
+        case: 述語に対する格．
+        arg_type: 項のタイプ．
+    """
+
+    def __init__(self, case: str, arg_type: ArgumentType) -> None:
+        self.case: str = case  #: 述語に対する格．
+        self.type: ArgumentType = arg_type  #: 項のタイプ．
+        self.optional: bool = False  #: 修飾的な項かどうか．
         self._pas: Optional["Pas"] = None
 
     @abstractmethod
@@ -51,13 +57,8 @@ class BaseArgument(ABC):
 
     @property
     def pas(self) -> "Pas":
-        """述語項構造．
-
-        Raises:
-            AttributeError: 述語項構造がセットされていない場合．
-        """
-        if self._pas is None:
-            raise AttributeError("pas has not been set")
+        """述語項構造．"""
+        assert self._pas is not None
         return self._pas
 
     @pas.setter
@@ -67,34 +68,39 @@ class BaseArgument(ABC):
 
 
 class EndophoraArgument(BaseArgument):
-    """文脈中の句を指す項を表すクラス．
+    """文脈中の基本句に対応する項を表すクラス．
 
     Args:
-        base_phrase: 照応詞が指す基本句．
+        case: 述語に対する格．
+        base_phrase: 項の核となる基本句．
         arg_type: 項のタイプ．
     """
 
-    def __init__(self, base_phrase: "BasePhrase", arg_type: ArgumentType) -> None:
-        super().__init__(arg_type)
+    def __init__(self, case: str, base_phrase: "BasePhrase", arg_type: ArgumentType) -> None:
+        super().__init__(case, arg_type)
         self.base_phrase = base_phrase  #: 項の核となる基本句．
 
     def __repr__(self) -> str:
-        return f"<{self.__module__}.{self.__class__.__name__}: {repr(self.base_phrase.text)}>"
+        return f"<{self.__module__}.{self.__class__.__name__}: {repr(self.case)}, {repr(self.base_phrase.text)}>"
 
     def __str__(self) -> str:
         return self.base_phrase.text
 
     def __eq__(self, other: Any) -> bool:
-        return isinstance(other, EndophoraArgument) and self.base_phrase == other.base_phrase
-
-    @property
-    def unit(self) -> "BasePhrase":
-        """項の核となる基本句．"""
-        return self.base_phrase
+        if isinstance(other, type(self)) is False:
+            return False
+        if self._pas is not None and other._pas is not None:
+            if self.pas.predicate != other.pas.predicate:
+                return False
+        return self.case == other.case and self.base_phrase == other.base_phrase
 
     @property
     def document(self) -> "Document":
-        """項の核となる基本句が属する文書．"""
+        """項の核となる基本句が属する文書．
+
+        Raises:
+            AttributeError: 解析結果にアクセスできない場合．
+        """
         return self.base_phrase.document
 
     @property
@@ -104,7 +110,11 @@ class EndophoraArgument(BaseArgument):
 
     @property
     def clause(self) -> "Clause":
-        """項の核となる基本句が属する節．"""
+        """項の核となる基本句が属する節．
+
+        Raises:
+            AttributeError: 解析結果にアクセスできない場合．
+        """
         return self.base_phrase.clause
 
     @property
@@ -114,26 +124,35 @@ class EndophoraArgument(BaseArgument):
 
 
 class ExophoraArgument(BaseArgument):
-    """外界を指す項を表すクラス．
+    """外界照応の照応先に対応する項を表すクラス．
 
     Args:
+        case: 述語に対する格．
         exophora_referent: 外界照応における照応先（不特定:人など）．
         eid: エンティティID．
     """
 
-    def __init__(self, exophora_referent: ExophoraReferent, eid: int) -> None:
-        super().__init__(ArgumentType.EXOPHORA)
+    def __init__(self, case: str, exophora_referent: ExophoraReferent, eid: int) -> None:
+        super().__init__(case, ArgumentType.EXOPHORA)
         self.exophora_referent = exophora_referent  #: 外界照応における照応先．
         self.eid = eid  #: エンティティID．
 
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}(exophora_referent={repr(self.exophora_referent)}, eid={repr(self.eid)})"
+        return (
+            f"{self.__class__.__name__}(case={repr(self.case)}, exophora_referent={repr(self.exophora_referent)}, "
+            f"eid={repr(self.eid)})"
+        )
 
     def __str__(self) -> str:
         return str(self.exophora_referent)
 
     def __eq__(self, other: Any) -> bool:
-        return isinstance(other, ExophoraArgument) and self.exophora_referent == other.exophora_referent
+        if isinstance(other, type(self)) is False:
+            return False
+        if self._pas is not None and other._pas is not None:
+            if self.pas.predicate != other.pas.predicate:
+                return False
+        return self.case == other.case and self.exophora_referent == other.exophora_referent
 
 
 Argument = Union[EndophoraArgument, ExophoraArgument]
